@@ -33,15 +33,14 @@ class InmofactoryAPI(object):
         )
 
     def _make_request(self, json_payload=None, method='POST', url='', params={}):
-        if json_payload:
-            json_payload = '=%s' % json_payload
-
-        response = requests.request(method, WEBSERVICE_URL + url, data=json_payload,
+        response = requests.request(method, WEBSERVICE_URL + url, json=json_payload,
                                     headers={'cache-control': 'no-cache',
                                              'content-type': 'application/json; charset=utf8',
-                                             'Authorization': 'Basic'},
+                                             'Authorization': 'Basic %s' % self.user_password_base64},
                                     params=params)
-        json_dict = json.loads(response.content)
+        response_content = response.content
+        response_content = response_content.replace("'", '"')
+        json_dict = json.loads(response_content)
         return json_dict
 
     def check_params(self, property_dict):
